@@ -13,6 +13,12 @@ import matplotlib.pyplot as plt
 from matplotlib import colors
 import seaborn as sns
 from tabulate import tabulate
+from sklearn.model_selection import train_test_split
+from sklearn.preprocessing import StandardScaler
+from sklearn import linear_model
+from sklearn.model_selection import cross_val_score, cross_val_predict
+import joblib
+from sklearn.linear_model import ElasticNet
 
 #################################### Funciones ##############################################
 
